@@ -1,3 +1,20 @@
+/*  Copyright 1996-2004,2007-2009 Alain Knaff.
+ *  This file is part of mtools.
+ *
+ *  Mtools is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Mtools is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with Mtools.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 #include "sysincludes.h"
 #include "msdos.h"
 #include "mtools.h"
@@ -15,6 +32,7 @@ static const struct dispatch {
 	{"mbadblocks",mbadblocks, 0},
 	{"mcat",mcat, 0},
 	{"mcd",mcd, 0},
+	{"mclasserase",mclasserase, 0},
 	{"mcopy",mcopy, 0},
 	{"mdel",mdel, 0},
 	{"mdeltree",mdel, 2},
@@ -41,8 +59,15 @@ static const struct dispatch {
 
 int main(int argc,char **argv)
 {
+	unsigned int i;
 	const char *name;
-	int i;
+
+#ifdef HAVE_SETLOCALE
+	char *locale;
+	locale=setlocale(LC_ALL, "");
+	if(locale == NULL || !strcmp(locale, "C"))
+		setlocale(LC_ALL, "en_US");
+#endif
 
 	init_privs();
 #ifdef __EMX__
@@ -93,7 +118,10 @@ int main(int argc,char **argv)
 
 #ifdef __EMX__
        argv[0] = _getname(argv[0]); _remext(argv[0]); name = argv[0];
-#else  
+#else
+#ifdef OS_mingw32msvc
+	_stripexe(argv[0]);
+#endif
 	name = _basename(argv[0]);
 #endif
 	progname = argv[0];
@@ -116,9 +144,8 @@ int main(int argc,char **argv)
 	/* print the version */
 	if(argc >= 2 && 
 	   (strcmp(argv[1], "-V") == 0 || strcmp(argv[1], "--version") ==0)) {
-		printf("%c%s version %s, dated %s\n", 
-		       toupper(name[0]), name+1,
-		       mversion, mdate);
+		printf("%s (GNU mtools) %s\n", 
+		       name, mversion);
 		printf("configured with the following options: ");
 #ifdef USE_XDF
 		printf("enable-xdf ");
@@ -135,7 +162,7 @@ int main(int argc,char **argv)
 #else
 		printf("disable-new-vold ");
 #endif
-#if DEBUG
+#ifdef DEBUG
 		printf("enable-debug ");
 #else
 		printf("disable-debug ");
@@ -167,3 +194,7 @@ int main(int argc,char **argv)
 
 	return 1;
 }
+
+int helpFlag(int argc, char **argv) {
+	return (argc > 1 && !strcmp(argv[1], "--help"));
+}
